package com.javacodegeeks.bolt;

import org.apache.http.HttpHost;
import org.apache.storm.task.TopologyContext;
import org.apache.storm.topology.BasicOutputCollector;
import org.apache.storm.topology.OutputFieldsDeclarer;
import org.apache.storm.topology.base.BaseBasicBolt;
import org.apache.storm.tuple.Tuple;
import org.elasticsearch.client.Request;
import org.elasticsearch.client.RestClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.util.Map;

/**
 * A bolt that sends data to ElasticSearch via REST.
 */
public class ElasticSearchBolt extends BaseBasicBolt {

    private static int count = 0;
    private static final Logger LOG = LoggerFactory.getLogger(ElasticSearchBolt.class);

    private RestClient restClient;

    @Override
    public void prepare(Map<String, Object> conf, TopologyContext context) {
        restClient = RestClient.builder(
                new HttpHost("10.0.2.2", 9200, "http")).build();
    }

    @Override
    public void execute(Tuple tuple, BasicOutputCollector basicOutputCollector) {
        String id = tuple.getStringByField("id");
        String index = tuple.getStringByField("index");
        String type = tuple.getStringByField("type");
        String source = tuple.getStringByField("source");

        String endPoint = "/" + index + "/" + type + "/" + id;
        Request request = new Request("POST", endPoint);
        request.setJsonEntity(source);

        if(++count %100 == 0) {
            LOG.info("Number of ES put requests: " + count);
        }
        LOG.debug("Sending request " + request);
        try {
            restClient.performRequest(request);
        } catch (IOException e) {
            LOG.error("Error during rest call", e);
        }
    }

    @Override
    public void declareOutputFields(OutputFieldsDeclarer outputFieldsDeclarer) {
        // nothing to declare
    }
}
