package com.javacodegeeks.topology;

import com.javacodegeeks.bolt.ElasticSearchBolt;
import org.apache.storm.LocalCluster;
import org.apache.storm.StormSubmitter;
import org.apache.storm.generated.StormTopology;
import org.apache.storm.topology.ConfigurableTopology;
import com.javacodegeeks.spout.FlightDataReaderSpout;
import org.apache.storm.utils.Utils;

import java.io.File;

/**
 * A topology that reads flight data from json files (spout {@link FlightDataReaderSpout})
 * and stores them to ElasticSearch ({@link ElasticSearchBolt} bolt).
 */
public class FlightPlanIndexingTopology extends ConfigurableTopology {
    private static final int FIVE_MINUTES = 300000;
    private static final String JSON_FILE_PATH = new File("src/main/resources/flightdata/2016-07-01-1300Z.json").getAbsolutePath();
    private static final String TOPOLOGY_NAME = "es-index-flights";

    public static void main(String[] args) {
        ConfigurableTopology.start(new FlightPlanIndexingTopology(), args);
    }

    @Override
    protected int run(String[] args) {
        // Create configuration
        conf.setDebug(true);
        conf.put("flightData", JSON_FILE_PATH);
        conf.setNumWorkers(2);

        // Build the topology
        final StormTopology topology = FlightPlanIndexingTopologyBuilder.build();
        // Run the topology
        try {
//            LocalCluster localCluster = new LocalCluster();
//            localCluster.submitTopology(TOPOLOGY_NAME, conf, topology);
            StormSubmitter stormCluster = new StormSubmitter();
            stormCluster.submitTopology(TOPOLOGY_NAME, conf, topology);
//            Utils.sleep(FIVE_MINUTES);
//            localCluster.killTopology(TOPOLOGY_NAME);
//            localCluster.shutdown();
        } catch (Exception e) {
            e.printStackTrace();
        }

        return 0;
    }
}
