package com.javacodegeeks.topology;

import com.javacodegeeks.spout.FlightDataReaderSpout;
import org.apache.http.Header;
import org.apache.http.HttpHeaders;
import org.apache.http.message.BasicHeader;
import org.apache.storm.elasticsearch.bolt.EsIndexBolt;
import org.apache.storm.elasticsearch.common.DefaultEsTupleMapper;
import org.apache.storm.elasticsearch.common.EsConfig;
import org.apache.storm.elasticsearch.common.EsTupleMapper;
import org.apache.storm.generated.StormTopology;
import org.apache.storm.topology.TopologyBuilder;

/**
 * Builds a topology. The topology consists of {@code FlightDataReaderSpout} and {@code ElasticSearchBolt}.
 */
public final class FlightPlanIndexingTopologyBuilder {

    private FlightPlanIndexingTopologyBuilder() {}

    public static StormTopology build() {
        TopologyBuilder builder = new TopologyBuilder();
        builder.setSpout("spout", new FlightDataReaderSpout());

        EsConfig esConfig = new EsConfig("http://10.0.2.2:9200");
        Header[] headers = new Header[1];
        headers[0]= new BasicHeader(HttpHeaders.CONTENT_TYPE, "application/json");
        esConfig.withDefaultHeaders(headers);
        EsTupleMapper tupleMapper = new DefaultEsTupleMapper();
        EsIndexBolt indexBolt = new EsIndexBolt(esConfig, tupleMapper);
        builder.setBolt("indexBolt", indexBolt).shuffleGrouping("spout");
        return builder.createTopology();
    }
}
